==> python2-faker-0.8.12-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/faker/providers/person/lv_LV/__init__.py <==
# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{last_name}}, {{first_name}}'
    )

    first_names = (
        'Ādams', 'Ādolfs', 'Agris', 'Aigars', 'Ainārs', 'Aivars', 'Alberts',
        'Aldis', 'Aleksandrs', 'Alfrēds', 'Andrejs', 'Andris', 'Andrešs', 'Ansis',
        'Antons', 'Armands', 'Arnis', 'Arnolds', 'Artis', 'Arturs', 'Artūrs', 'Arvīds',
        'Augusts', 'Bērends', 'Bērtulis', 'Brencis', 'Dainis', 'Daniels', 'Dāvis',
        'Dzintars', 'Edgars', 'Edmunds', 'Eduards', 'Edvīns', 'Egils', 'Elmārs', 'Elvis',
        'Emīls', 'Ēriks', 'Ermanis', 'Ernests', 'Ēvalds', 'Fricis', 'Gatis', 'Gunārs',
        'Guntars', 'Guntis', 'Ģederts', 'Ģirts', 'Hanss', 'Harijs', 'Henriks', 'Hermanis',
        'Igors', 'Ilmārs', 'Imants', 'Indriķis', 'Ivars', 'Ivo', 'Jakobs', 'Janis', 'Jānis',
        'Jannis', 'Jāzeps', 'Jēkabs', 'Jēkaubs', 'Jezups', 'Johans', 'Jūlijs', 'Juris', 'Kārlis',
        'Kaspars', 'Konradus', 'Kristaps', 'Kristers', 'Krists', 'Krišjānis', 'Krišs', 'Laimonis',
        'Lauris', 'Leons', 'Macs', 'Mareks', 'Māris', 'Mārtiņš', 'Matīss', 'Mihels', 'Mikels',
        'Miķelis', 'Modris', 'Nikolajs', 'Niks', 'Normunds', 'Oļģerts', 'Oskars', 'Osvalds',
        'Oto', 'Pauls', 'Pēteris', 'Raimonds', 'Raivis', 'Reinis', 'Ričards', 'Rihards', 'Roberts',
        'Rolands', 'Rūdolfs', 'Sandis', 'Staņislavs', 'Tenis', 'Teodors', 'Toms', 'Uldis', 'Valdis',
        'Viesturs', 'Viktors', 'Vilis', 'Vilnis', 'Viļums', 'Visvaldis', 'Vladislavs', 'Voldemārs',
        'Ziedonis', 'Žanis', 'Agnese', 'Aiga', 'Aija', 'Aina', 'Alīda', 'Alise', 'Alma', 'Alvīne',
        'Amālija', 'Anete', 'Anita', 'Anna', 'Annija', 'Antoņina', 'Antra', 'Ārija', 'Ausma', 'Austra',
        'Baba', 'Baiba', 'Berta', 'Biruta', 'Broņislava', 'Dace', 'Daiga', 'Daina', 'Dārta', 'Diāna',
        'Doroteja', 'Dzidra', 'Dzintra', 'Eda', 'Edīte', 'Elīna', 'Elita', 'Elizabete', 'Elvīra', 'Elza',
        'Emīlija', 'Emma', 'Ērika', 'Erna', 'Eva', 'Evija', 'Evita', 'Gaida', 'Genovefa', 'Grēta', 'Grieta',
        'Gunita', 'Gunta', 'Helēna', 'Ieva', 'Ilga', 'Ilona', 'Ilze', 'Ina', 'Ināra', 'Indra', 'Inese', 'Ineta',
        'Inga', 'Ingrīda', 'Inguna', 'Inta', 'Irēna', 'Irma', 'Iveta', 'Jana', 'Janina', 'Jūle', 'Jūla',
        'Jūlija', 'Karina', 'Karlīna', 'Katarīna', 'Katrīna', 'Krista', 'Kristiāna', 'Laila', 'Laura',
        'Lavīze', 'Leontīne', 'Lība', 'Lidija', 'Liene', 'Līga', 'Ligita', 'Lilija', 'Lilita', 'Līna',
        'Linda', 'Līza', 'Lizete', 'Lūcija', 'Madara', 'Made', 'Maija', 'Māra', 'Mare', 'Margareta', 'Margrieta',
        'Marija', 'Mārīte', 'Marta', 'Maža', 'Milda', 'Minna', 'Mirdza', 'Monika', 'Natālija', 'Olga', 'Otīlija',
        'Paula', 'Paulīna', 'Rasma', 'Regīna', 'Rita', 'Rudīte', 'Ruta', 'Rute', 'Samanta', 'Sandra', 'Sanita',
        'Santa', 'Sapa', 'Sarmīte', 'Silvija', 'Sintija', 'Skaidrīte', 'Solvita', 'Tekla', 'Trīne', 'Valda',
        'Valentīna', 'Valija', 'Velta', 'Veneranda', 'Vera', 'Veronika', 'Vija', 'Vilma', 'Vineta', 'Vita', 'Zane',
        'Zelma', 'Zenta', 'Zigrīda'
    )

    last_names = (
        'Ābele',
        'Āboliņš',
        'Ābols',
        'Alksnis',
        'Apinis',
        'Apsītis',
        'Auniņš',
        'Auziņš',
        'Avotiņš',
        'Balodis',
        'Baltiņš',
        'Bērziņš',
        'Birznieks',
        'Bite',
        'Briedis',
        'Caune',
        'Celmiņš',
        'Celms',
        'Cīrulis',
        'Dzenis',
        'Dūmiņš',
        'Eglītis',
        'Jaunzems',
        'Kalējs',
        'Kalniņš',
        'Kaņeps',
        'Kārkliņš',
        'Kauliņš',
        'Kļaviņš',
        'Krastiņš',
        'Krēsliņš',
        'Krieviņš',
        'Krievs',
        'Krūmiņš',
        'Krūze',
        'Kundziņš',
        'Lācis',
        'Lagzdiņš',
        'Lapsa',
        'Līcis',
        'Liepa',
        'Liepiņš',
        'Lukstiņš',
        'Lūsis',
        'Paegle',
        'Pērkons',
        'Podnieks',
        'Polis',
        'Priede',
        'Priedītis',
        'Puriņš',
        'Purmals',
        'Riekstiņš',
        'Roze',
        'Rozītis',
        'Rubenis',
        'Rudzītis',
        'Saulītis',
        'Siliņš',
        'Skuja',
        'Skujiņš',
        'Sproģis',
        'Strazdiņš',
        'Turiņš',
        'Vanags',
        'Vīksna',
        'Vilciņš',
        'Vilks',
        'Vītoliņš',
        'Vītols',
        'Zaķis',
        'Zālītis',
        'Zariņš',
        'Zeltiņš',
        'Ziemelis',
        'Zirnis',
        'Zvaigzne',
        'Zvirbulis')

==> python2-faker-1.0.2-1-any.pkg.tar.xz: usr/lib/python2.7/site-packages/faker/providers/person/lv_LV/__init__.py <==
# -*- coding: utf-8 -*-

from __future__ import unicode_literals
from .. import Provider as PersonProvider


class Provider(PersonProvider):
    formats = (
        '{{first_name}} {{last_name}}',
        '{{first_name}} {{last_name}}',
        '{{last_name}}, {{first_name}}',
    )

    first_names = (
        'Ādams', 'Ādolfs', 'Agris', 'Aigars', 'Ainārs', 'Aivars', 'Alberts',
        'Aldis', 'Aleksandrs', 'Alfrēds', 'Andrejs', 'Andris', 'Andrešs', 'Ansis',
        'Antons', 'Armands', 'Arnis', 'Arnolds', 'Artis', 'Arturs', 'Artūrs', 'Arvīds',
        'Augusts', 'Bērends', 'Bērtulis', 'Brencis', 'Dainis', 'Daniels', 'Dāvis',
        'Dzintars', 'Edgars', 'Edmunds', 'Eduards', 'Edvīns', 'Egils', 'Elmārs', 'Elvis',
        'Emīls', 'Ēriks', 'Ermanis', 'Ernests', 'Ēvalds', 'Fricis', 'Gatis', 'Gunārs',
        'Guntars', 'Guntis', 'Ģederts', 'Ģirts', 'Hanss', 'Harijs', 'Henriks', 'Hermanis',
        'Igors', 'Ilmārs', 'Imants', 'Indriķis', 'Ivars', 'Ivo', 'Jakobs', 'Janis', 'Jānis',
        'Jannis', 'Jāzeps', 'Jēkabs', 'Jēkaubs', 'Jezups', 'Johans', 'Jūlijs', 'Juris', 'Kārlis',
        'Kaspars', 'Konradus', 'Kristaps', 'Kristers', 'Krists', 'Krišjānis', 'Krišs', 'Laimonis',
        'Lauris', 'Leons', 'Macs', 'Mareks', 'Māris', 'Mārtiņš', 'Matīss', 'Mihels', 'Mikels',
        'Miķelis', 'Modris', 'Nikolajs', 'Niks', 'Normunds', 'Oļģerts', 'Oskars', 'Osvalds',
        'Oto', 'Pauls', 'Pēteris', 'Raimonds', 'Raivis', 'Reinis', 'Ričards', 'Rihards', 'Roberts',
        'Rolands', 'Rūdolfs', 'Sandis', 'Staņislavs', 'Tenis', 'Teodors', 'Toms', 'Uldis', 'Valdis',
        'Viesturs', 'Viktors', 'Vilis', 'Vilnis', 'Viļums', 'Visvaldis', 'Vladislavs', 'Voldemārs',
        'Ziedonis', 'Žanis', 'Agnese', 'Aiga', 'Aija', 'Aina', 'Alīda', 'Alise', 'Alma', 'Alvīne',
        'Amālija', 'Anete', 'Anita', 'Anna', 'Annija', 'Antoņina', 'Antra', 'Ārija', 'Ausma', 'Austra',
        'Baba', 'Baiba', 'Berta', 'Biruta', 'Broņislava', 'Dace', 'Daiga', 'Daina', 'Dārta', 'Diāna',
        'Doroteja', 'Dzidra', 'Dzintra', 'Eda', 'Edīte', 'Elīna', 'Elita', 'Elizabete', 'Elvīra', 'Elza',
        'Emīlija', 'Emma', 'Ērika', 'Erna', 'Eva', 'Evija', 'Evita', 'Gaida', 'Genovefa', 'Grēta', 'Grieta',
        'Gunita', 'Gunta', 'Helēna', 'Ieva', 'Ilga', 'Ilona', 'Ilze', 'Ina', 'Ināra', 'Indra', 'Inese', 'Ineta',
        'Inga', 'Ingrīda', 'Inguna', 'Inta', 'Irēna', 'Irma', 'Iveta', 'Jana', 'Janina', 'Jūle', 'Jūla',
        'Jūlija', 'Karina', 'Karlīna', 'Katarīna', 'Katrīna', 'Krista', 'Kristiāna', 'Laila', 'Laura',
        'Lavīze', 'Leontīne', 'Lība', 'Lidija', 'Liene', 'Līga', 'Ligita', 'Lilija', 'Lilita', 'Līna',
        'Linda', 'Līza', 'Lizete', 'Lūcija', 'Madara', 'Made', 'Maija', 'Māra', 'Mare', 'Margareta', 'Margrieta',
        'Marija', 'Mārīte', 'Marta', 'Maža', 'Milda', 'Minna', 'Mirdza', 'Monika', 'Natālija', 'Olga', 'Otīlija',
        'Paula', 'Paulīna', 'Rasma', 'Regīna', 'Rita', 'Rudīte', 'Ruta', 'Rute', 'Samanta', 'Sandra', 'Sanita',
        'Santa', 'Sapa', 'Sarmīte', 'Silvija', 'Sintija', 'Skaidrīte', 'Solvita', 'Tekla', 'Trīne', 'Valda',
        'Valentīna', 'Valija', 'Velta', 'Veneranda', 'Vera', 'Veronika', 'Vija', 'Vilma', 'Vineta', 'Vita', 'Zane',
        'Zelma', 'Zenta', 'Zigrīda',
    )

    last_names = (
        'Ābele',
        'Āboliņš',
        'Ābols',
        'Alksnis',
        'Apinis',
        'Apsītis',
        'Auniņš',
        'Auziņš',
        'Avotiņš',
        'Balodis',
        'Baltiņš',
        'Bērziņš',
        'Birznieks',
        'Bite',
        'Briedis',
        'Caune',
        'Celmiņš',
        'Celms',
        'Cīrulis',
        'Dzenis',
        'Dūmiņš',
        'Eglītis',
        'Jaunzems',
        'Kalējs',
        'Kalniņš',
        'Kaņeps',
        'Kārkliņš',
        'Kauliņš',
        'Kļaviņš',
        'Krastiņš',
        'Krēsliņš',
        'Krieviņš',
        'Krievs',
        'Krūmiņš',
        'Krūze',
        'Kundziņš',
        'Lācis',
        'Lagzdiņš',
        'Lapsa',
        'Līcis',
        'Liepa',
        'Liepiņš',
        'Lukstiņš',
        'Lūsis',
        'Paegle',
        'Pērkons',
        'Podnieks',
        'Polis',
        'Priede',
        'Priedītis',
        'Puriņš',
        'Purmals',
        'Riekstiņš',
        'Roze',
        'Rozītis',
        'Rubenis',
        'Rudzītis',
        'Saulītis',
        'Siliņš',
        'Skuja',
        'Skujiņš',
        'Sproģis',
        'Strazdiņš',
        'Turiņš',
        'Vanags',
        'Vīksna',
        'Vilciņš',
        'Vilks',
        'Vītoliņš',
        'Vītols',
        'Zaķis',
        'Zālītis',
        'Zariņš',
        'Zeltiņš',
        'Ziemelis',
        'Zirnis',
        'Zvaigzne',
        'Zvirbulis')
